from typing import TYPE_CHECKING

from sqlalchemy.orm import Mapped, relationship

from ..db.base_class import reg
from .account_base import AccountBase


if TYPE_CHECKING:
    from .product import Product


@reg.mapped_as_dataclass(unsafe_hash=True)
class Account(AccountBase):
    __mapper_args__ = {"polymorphic_identity": ""}  # type: ignore

    products: Mapped[list["Product"]] = relationship(
        "Product", primaryjoin="Account.id==Product.account_id", back_populates="account"
    )

    def can_delete(self, advanced_delete: bool) -> tuple[bool, str]:
        if len(self.products) > 0:
            return False, "Account has products"
        return super(Account, self).can_delete(advanced_delete)
