from typing import TYPE_CHECKING

from sqlalchemy import Boolean, Integer, Unicode
from sqlalchemy.orm import Mapped, mapped_column, relationship

from ..db.base_class import reg


if TYPE_CHECKING:
    # if the target of the relationship is in another module
    # that cannot normally be imported at runtime
    from .account import AccountBase


@reg.mapped_as_dataclass(unsafe_hash=True)
class AccountType:
    __tablename__ = "account_types"

    id: Mapped[int] = mapped_column(Integer, primary_key=True)
    name: Mapped[str] = mapped_column(Unicode, unique=True, nullable=False)
    balance_sheet: Mapped[bool] = mapped_column(Boolean, nullable=False)
    debit: Mapped[bool] = mapped_column(Boolean, nullable=False)
    cash_flow_classification: Mapped[str] = mapped_column(Unicode, nullable=False)
    order: Mapped[int] = mapped_column(Integer, nullable=False)
    show_in_list: Mapped[bool] = mapped_column(Boolean, nullable=False)

    accounts: Mapped[list["AccountBase"]] = relationship("AccountBase", back_populates="type_")
