import uuid

from typing import TYPE_CHECKING

from sqlalchemy import Unicode, Uuid
from sqlalchemy.orm import Mapped, mapped_column, relationship

from ..db.base_class import reg
from .recipe_tag import RecipeTag


if TYPE_CHECKING:
    from .recipe import Recipe


@reg.mapped_as_dataclass(unsafe_hash=True)
class Tag:
    __tablename__ = "tags"

    id: Mapped[uuid.UUID] = mapped_column(Uuid, primary_key=True, insert_default=uuid.uuid4)
    name: Mapped[str] = mapped_column(Unicode, unique=True, nullable=False)

    recipes: Mapped[list["Recipe"]] = relationship(
        "Recipe", secondary=RecipeTag.__table__, order_by="Recipe.date_", back_populates="tags"
    )
