import uuid

from datetime import date, datetime

from brewman.schemas import to_camel
from brewman.schemas.attendance_type import AttendanceType
from pydantic import (
    BaseModel,
    ConfigDict,
    FieldSerializationInfo,
    field_serializer,
    field_validator,
)


class AttendanceItem(BaseModel):
    id_: uuid.UUID
    code: int
    name: str
    designation: str
    department: str
    attendance_type: AttendanceType
    prints: str
    hours_worked: str
    full_day: bool | None = None
    model_config = ConfigDict(alias_generator=to_camel, populate_by_name=True)


class Attendance(BaseModel):
    date_: date | None = None
    body: list[AttendanceItem]
    model_config = ConfigDict(str_strip_whitespace=True, alias_generator=to_camel, populate_by_name=True)

    @field_validator("date_", mode="before")
    @classmethod
    def parse_date(cls, value: date | str) -> date:
        if isinstance(value, date):
            return value
        return datetime.strptime(value, "%d-%b-%Y").date()

    @field_serializer("date_")
    def serialize_date(self, value: date, info: FieldSerializationInfo) -> str:
        return value.strftime("%d-%b-%Y")
