import { HttpClient, HttpParams } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs/internal/Observable';
import { catchError } from 'rxjs/operators';

import { ErrorLoggerService } from '../core/error-logger.service';

import { ProductLedger } from './product-ledger';

const url = '/api/product-ledger';
const serviceName = 'ProductLedgerService';

@Injectable({
  providedIn: 'root',
})
export class ProductLedgerService {
  constructor(
    private http: HttpClient,
    private log: ErrorLoggerService,
  ) {}

  list(
    id: string | null,
    startDate: string | null,
    finishDate: string | null,
  ): Observable<ProductLedger> {
    const listUrl = id === null ? url : `${url}/${id}`;
    const options = { params: new HttpParams() };
    if (startDate !== null) {
      options.params = options.params.set('s', startDate);
    }
    if (finishDate !== null) {
      options.params = options.params.set('f', finishDate);
    }
    return this.http
      .get<ProductLedger>(listUrl, options)
      .pipe(catchError(this.log.handleError(serviceName, 'list'))) as Observable<ProductLedger>;
  }
}
