import { CommonModule } from '@angular/common';
import { NgModule, inject } from '@angular/core';
import { ActivatedRouteSnapshot, RouterModule, RouterStateSnapshot, Routes } from '@angular/router';

import { AccountTypeResolver } from '../account/account-type-resolver.service';
import { AuthGuard } from '../auth/auth-guard.service';

import { LockInformationResolver } from './lock-information-resolver.service';
import { MaintenanceResolver } from './maintenance-resolver.service';
import { SettingsComponent } from './settings.component';
import { VoucherTypeResolver } from './voucher-type-resolver.service';

const settingsRoutes: Routes = [
  {
    path: '',
    component: SettingsComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) =>
        inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Maintenance', // 'Lock Date'
    },
    resolve: {
      maintenance: () => inject(MaintenanceResolver).resolve(),
      lockInformation: () => inject(LockInformationResolver).resolve(),
      accountTypes: () => inject(AccountTypeResolver).resolve(),
      voucherTypes: () => inject(VoucherTypeResolver).resolve(),
    },
    runGuardsAndResolvers: 'always',
  },
];

@NgModule({
  imports: [CommonModule, RouterModule.forChild(settingsRoutes)],
  exports: [RouterModule],
})
export class SettingsRoutingModule {}
