import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs/internal/Observable';
import { catchError } from 'rxjs/operators';

import { ErrorLoggerService } from '../core/error-logger.service';

import { LockInfo } from './lock-info';

const serviceName = 'SettingsService';

@Injectable({ providedIn: 'root' })
export class SettingsService {
  constructor(
    private http: HttpClient,
    private log: ErrorLoggerService,
  ) {}

  getLockInformation(): Observable<[LockInfo]> {
    const url = '/api/lock-information';
    return this.http
      .get<[LockInfo]>(url)
      .pipe(catchError(this.log.handleError(serviceName, 'getLockInformation'))) as Observable<
      [LockInfo]
    >;
  }

  setLockInformation(lockInformation: LockInfo): Observable<LockInfo[]> {
    const url = '/api/lock-information';
    return this.http
      .post<LockInfo[]>(url, lockInformation)
      .pipe(catchError(this.log.handleError(serviceName, 'setLockInformation'))) as Observable<
      LockInfo[]
    >;
  }

  deleteLockInformation(id: string): Observable<LockInfo[]> {
    const url = '/api/lock-information';
    return this.http
      .delete<LockInfo[]>(`${url}/${id}`)
      .pipe(catchError(this.log.handleError(serviceName, 'deleteLockInformation'))) as Observable<
      LockInfo[]
    >;
  }

  rebaseDatabase(date: string): Observable<Record<string, never>> {
    const url = '/api/rebase';
    return this.http
      .post<Record<string, never>>(`${url}/${date}`, {})
      .pipe(catchError(this.log.handleError(serviceName, 'rebaseDatabase'))) as Observable<
      Record<string, never>
    >;
  }

  setMaintenance(enable: boolean): Observable<{ enabled: boolean; user: string }> {
    const url = '/api/maintenance';
    return this.http
      .post<{ enabled: boolean; user: string }>(url, { enabled: enable })
      .pipe(catchError(this.log.handleError(serviceName, 'setMaintenance'))) as Observable<{
      enabled: boolean;
      user: string;
    }>;
  }

  getMaintenance(): Observable<{ enabled: boolean; user: string }> {
    const url = '/api/maintenance';
    return this.http
      .get<{ enabled: boolean; user: string }>(url)
      .pipe(catchError(this.log.handleError(serviceName, 'getMaintenance'))) as Observable<{
      enabled: boolean;
      user: string;
    }>;
  }

  checkDatabaseIntegrity(): Observable<{ attendanceCount: number }> {
    const url = '/api/db-integrity';
    return this.http
      .post<{ attendanceCount: number }>(url, {})
      .pipe(catchError(this.log.handleError(serviceName, 'checkDatabaseIntegrity'))) as Observable<{
      attendanceCount: number;
    }>;
  }
}
